---
title: "Urubu 0.9.0 released"
layout: page 
date: 2015-12-15
---

This release adds support for Tipue Search, an open source search solution
based on Javascript in the browser.

Read more in the chapter [/manual/search] in the manual.
